require 'helper'

class TestExvoAuth < Test::Unit::TestCase
  def setup
    Exvo::Helpers.auth_client_id     = "foo"
    Exvo::Helpers.auth_client_secret = "bar"
  end

  test "consumer sanity" do
    c = ExvoAuth::Autonomous::Consumer.new(:app_id => "baz")
    authorization = { "access_token" => "qux", "url" => "https://foo/api" }
    auth = stub(:get => { "authorization" => authorization })
    c.expects(:auth).returns(auth)

    assert_equal authorization, c.send(:authorization)
    assert_equal authorization, c.send(:authorization) # second time from cache, without touching httparty
  end

  test "provider sanity" do
    p = ExvoAuth::Autonomous::Provider.new(:app_id => "baz", :access_token => "qux")
    auth = stub(:get => {"scope" => "qux quux"})
    p.expects(:auth).returns(auth)

    assert_equal ["qux", "quux"], p.scopes
    assert_equal ["qux", "quux"], p.scopes # second time from cache, without touching httparty
  end

  test "integration of httparty interface with auth" do
    c = ExvoAuth::Autonomous::Consumer.new(:app_id => "baz")
    basement = mock("basement")
    basement.expects(:base_uri)
    basement.expects(:basic_auth)
    basement.expects(:get).with("/bar").returns(true)
    c.expects(:basement).at_least_once.returns(basement)
    assert_true c.get("/bar")
  end

  test "basement includes httparty" do
    c = ExvoAuth::Autonomous::Consumer.new(:app_id => "baz")
    assert_true c.send(:basement).included_modules.include?(HTTParty)
  end

  test "storing full request with query params in the session" do
    class Controller
      include ExvoAuth::Controllers::Base
    end

    c = Controller.new
    c.expects(:unobtrusively_authenticate_user!)
    c.expects(:signed_in?).returns(false)

    original_fullpath = '/inbox?query=yes'
    request = stub(:original_fullpath => original_fullpath, :get? => true)
    c.stubs(:request).returns(request)

    session = {}
    c.stubs(:session => session)

    c.stubs(:params => {})
    c.expects(:redirect_to).with(c.sign_in_path)

    c.authenticate_user!

    assert_equal original_fullpath, session[:user_return_to]
  end
end
